@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals, absolute_import
 
@@ -111,6 +110,14 @@ class Query(UnicodeMixin):
                 raise ParsingException(msg)
         return field, lookup, val
 
+    def _escape(self, s):
+        r = []
+        for c in text_type(s):
+            if c in '+-&|!(){}[]^"~*?:\\':
+                r.append('\\')
+            r.append(c)
+        return ''.join(r)
+
     def _cast(self, val, lookup=None):
         if isinstance(val, bool):
             return '"{}"'.format(text_type(val).lower())
@@ -122,6 +129,8 @@ class Query(UnicodeMixin):
         if isinstance(val, Query):
             return text_type(val)
 
+        val = self._escape(val)
+
         if lookup == 'startswith':
             val = '{}*'.format(val)
         elif lookup == 'endswith':
